"""Smoke tests for src/pact/diagnoser.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_diagnoser():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.diagnoser")
    assert mod is not None

def test_diagnose_failure_is_callable():
    """Function diagnose_failure exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.diagnoser")
    fn = getattr(mod, "diagnose_failure", None)
    assert fn is not None, "'diagnose_failure' not found in pact.diagnoser"
    assert callable(fn)

def test_determine_recovery_action_is_callable():
    """Function determine_recovery_action exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.diagnoser")
    fn = getattr(mod, "determine_recovery_action", None)
    assert fn is not None, "'determine_recovery_action' not found in pact.diagnoser"
    assert callable(fn)
