"""Smoke tests for src/pact/project.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_project():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.project")
    assert mod is not None

def test_write_artifact_metadata_is_callable():
    """Function write_artifact_metadata exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.project")
    fn = getattr(mod, "write_artifact_metadata", None)
    assert fn is not None, "'write_artifact_metadata' not found in pact.project"
    assert callable(fn)

def test_read_artifact_metadata_is_callable():
    """Function read_artifact_metadata exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.project")
    fn = getattr(mod, "read_artifact_metadata", None)
    assert fn is not None, "'read_artifact_metadata' not found in pact.project"
    assert callable(fn)
