"""Smoke tests for src/pact/config.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_config():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.config")
    assert mod is not None

def test_load_global_config_is_callable():
    """Function load_global_config exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "load_global_config", None)
    assert fn is not None, "'load_global_config' not found in pact.config"
    assert callable(fn)

def test_load_project_config_is_callable():
    """Function load_project_config exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "load_project_config", None)
    assert fn is not None, "'load_project_config' not found in pact.config"
    assert callable(fn)

def test_resolve_model_is_callable():
    """Function resolve_model exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "resolve_model", None)
    assert fn is not None, "'resolve_model' not found in pact.config"
    assert callable(fn)

def test_resolve_backend_is_callable():
    """Function resolve_backend exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "resolve_backend", None)
    assert fn is not None, "'resolve_backend' not found in pact.config"
    assert callable(fn)

def test_resolve_model_tiers_is_callable():
    """Function resolve_model_tiers exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "resolve_model_tiers", None)
    assert fn is not None, "'resolve_model_tiers' not found in pact.config"
    assert callable(fn)

def test_resolve_build_mode_is_callable():
    """Function resolve_build_mode exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "resolve_build_mode", None)
    assert fn is not None, "'resolve_build_mode' not found in pact.config"
    assert callable(fn)

def test_resolve_parallel_config_is_callable():
    """Function resolve_parallel_config exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "resolve_parallel_config", None)
    assert fn is not None, "'resolve_parallel_config' not found in pact.config"
    assert callable(fn)

def test_resolve_environment_is_callable():
    """Function resolve_environment exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "resolve_environment", None)
    assert fn is not None, "'resolve_environment' not found in pact.config"
    assert callable(fn)

def test_resolve_timeout_config_is_callable():
    """Function resolve_timeout_config exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.config")
    fn = getattr(mod, "resolve_timeout_config", None)
    assert fn is not None, "'resolve_timeout_config' not found in pact.config"
    assert callable(fn)
