"""Smoke tests for src/pact/budget.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_budget():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.budget")
    assert mod is not None

def test_set_model_pricing_table_is_callable():
    """Function set_model_pricing_table exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.budget")
    fn = getattr(mod, "set_model_pricing_table", None)
    assert fn is not None, "'set_model_pricing_table' not found in pact.budget"
    assert callable(fn)

def test_get_model_pricing_table_is_callable():
    """Function get_model_pricing_table exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.budget")
    fn = getattr(mod, "get_model_pricing_table", None)
    assert fn is not None, "'get_model_pricing_table' not found in pact.budget"
    assert callable(fn)

def test_pricing_for_model_is_callable():
    """Function pricing_for_model exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.budget")
    fn = getattr(mod, "pricing_for_model", None)
    assert fn is not None, "'pricing_for_model' not found in pact.budget"
    assert callable(fn)

def test_estimate_tokens_is_callable():
    """Function estimate_tokens exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.budget")
    fn = getattr(mod, "estimate_tokens", None)
    assert fn is not None, "'estimate_tokens' not found in pact.budget"
    assert callable(fn)

def test_load_pricing_file_is_callable():
    """Function load_pricing_file exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.budget")
    fn = getattr(mod, "load_pricing_file", None)
    assert fn is not None, "'load_pricing_file' not found in pact.budget"
    assert callable(fn)

def test_save_pricing_file_is_callable():
    """Function save_pricing_file exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.budget")
    fn = getattr(mod, "save_pricing_file", None)
    assert fn is not None, "'save_pricing_file' not found in pact.budget"
    assert callable(fn)
