"""Smoke tests for src/pact/sentinel.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_sentinel():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.sentinel")
    assert mod is not None
