"""Smoke tests for src/pact/contracts.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_contracts():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    assert mod is not None

def test_extract_base_types_is_callable():
    """Function extract_base_types exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "extract_base_types", None)
    assert fn is not None, "'extract_base_types' not found in pact.contracts"
    assert callable(fn)

def test_validate_type_references_is_callable():
    """Function validate_type_references exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_type_references", None)
    assert fn is not None, "'validate_type_references' not found in pact.contracts"
    assert callable(fn)

def test_validate_dependency_graph_is_callable():
    """Function validate_dependency_graph exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_dependency_graph", None)
    assert fn is not None, "'validate_dependency_graph' not found in pact.contracts"
    assert callable(fn)

def test_validate_contract_completeness_is_callable():
    """Function validate_contract_completeness exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_contract_completeness", None)
    assert fn is not None, "'validate_contract_completeness' not found in pact.contracts"
    assert callable(fn)

def test_validate_test_suite_is_callable():
    """Function validate_test_suite exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_test_suite", None)
    assert fn is not None, "'validate_test_suite' not found in pact.contracts"
    assert callable(fn)

def test_normalize_dependency_name_is_callable():
    """Function normalize_dependency_name exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "normalize_dependency_name", None)
    assert fn is not None, "'normalize_dependency_name' not found in pact.contracts"
    assert callable(fn)

def test_validate_all_contracts_is_callable():
    """Function validate_all_contracts exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_all_contracts", None)
    assert fn is not None, "'validate_all_contracts' not found in pact.contracts"
    assert callable(fn)

def test_validate_contract_incremental_is_callable():
    """Function validate_contract_incremental exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_contract_incremental", None)
    assert fn is not None, "'validate_contract_incremental' not found in pact.contracts"
    assert callable(fn)

def test_validate_external_dependencies_is_callable():
    """Function validate_external_dependencies exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_external_dependencies", None)
    assert fn is not None, "'validate_external_dependencies' not found in pact.contracts"
    assert callable(fn)

def test_validate_hierarchy_locality_is_callable():
    """Function validate_hierarchy_locality exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_hierarchy_locality", None)
    assert fn is not None, "'validate_hierarchy_locality' not found in pact.contracts"
    assert callable(fn)

def test_validate_cross_component_interfaces_is_callable():
    """Function validate_cross_component_interfaces exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_cross_component_interfaces", None)
    assert fn is not None, "'validate_cross_component_interfaces' not found in pact.contracts"
    assert callable(fn)

def test_validate_north_star_is_callable():
    """Function validate_north_star exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_north_star", None)
    assert fn is not None, "'validate_north_star' not found in pact.contracts"
    assert callable(fn)

def test_validate_decomposition_coverage_is_callable():
    """Function validate_decomposition_coverage exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.contracts")
    fn = getattr(mod, "validate_decomposition_coverage", None)
    assert fn is not None, "'validate_decomposition_coverage' not found in pact.contracts"
    assert callable(fn)
